==> octave-2.9.14.tar.gz: octave-2.9.14/liboctave/int32NDArray.cc <==
// N-D Array  manipulations.
/*

Copyright (C) 2004 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301, USA.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "int32NDArray.h"

#include "intNDArray.cc"

template class OCTAVE_API intNDArray<octave_int32>;

template OCTAVE_API
std::ostream&
operator << (std::ostream& os, const intNDArray<octave_int32>& a);

template OCTAVE_API
std::istream&
operator >> (std::istream& is, intNDArray<octave_int32>& a);

NDS_CMP_OPS (int32NDArray, , octave_int32, )
NDS_BOOL_OPS (int32NDArray, octave_int32, octave_int32 (0))

SND_CMP_OPS (octave_int32, , int32NDArray, )
SND_BOOL_OPS (octave_int32, int32NDArray, octave_int32 (0))

NDND_CMP_OPS (int32NDArray, , int32NDArray, )
NDND_BOOL_OPS (int32NDArray, int32NDArray, octave_int32 (0))

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/

==> octave-3.2.2.tar.gz: octave-3.2.2/liboctave/int32NDArray.cc <==
// N-D Array  manipulations.
/*

Copyright (C) 2004, 2005, 2006, 2007, 2009 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "int32NDArray.h"
#include "mx-op-defs.h"
#include "intNDArray.cc"

template class OCTAVE_API intNDArray<octave_int32>;

template OCTAVE_API
std::ostream&
operator << (std::ostream& os, const intNDArray<octave_int32>& a);

template OCTAVE_API
std::istream&
operator >> (std::istream& is, intNDArray<octave_int32>& a);

NDS_CMP_OPS (int32NDArray, , octave_int32, )
NDS_BOOL_OPS (int32NDArray, octave_int32, octave_int32 (0))

SND_CMP_OPS (octave_int32, , int32NDArray, )
SND_BOOL_OPS (octave_int32, int32NDArray, octave_int32 (0))

NDND_CMP_OPS (int32NDArray, , int32NDArray, )
NDND_BOOL_OPS (int32NDArray, int32NDArray, octave_int32 (0))

MINMAX_FCNS (int32)

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/
